import {
  OnChange,
  AnyInput,
  inputClass,
  PluginComponent,
  PluginsProp,
  Field,
  InputProps,
} from "react-with-native-form";
import { Toggle } from "react-with-native";

const ToggleInput = ({
  onChange,
  value,
  extra,
  config,
  hasError,
}: InputProps<ToggleInputType>) => {
  config = config || {};

  const defaultClass = "";

  const errorClass = hasError
    ? config.errorClassName
      ? config.errorClassName
      : " border border-red-400"
    : "";

  const classWithError = config.replaceClassName
    ? `${config.replaceClassName} ${errorClass}`
    : `${defaultClass} ${config.extraClassName} ${errorClass}`;

  return (
    <Toggle
      className={classWithError}
      value={value}
      onChange={(value: ToggleInputType["value"]) => onChange(value)}
    />
  );
};

export interface ToggleInputType extends AnyInput {
  type: "toggle";
  /**
   * value type
   */
  value: boolean;

  defaultValue: false;

  /**
   * input generic configuration
   */
  config?: {
    errorClassName?: string;
    extraClassName?: string;
    replaceClassName?: string;
  };
  /**
   * field specific configuration
   */
  extra?: { disabled?: boolean; label?: string };
}

export default ToggleInput;
